summaryrefslogtreecommitdiff
path: root/Tonokip_Firmware/configuration.h
diff options
context:
space:
mode:
Diffstat (limited to 'Tonokip_Firmware/configuration.h')
-rw-r--r--Tonokip_Firmware/configuration.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/Tonokip_Firmware/configuration.h b/Tonokip_Firmware/configuration.h
index 8d822bb..c127e91 100644
--- a/Tonokip_Firmware/configuration.h
+++ b/Tonokip_Firmware/configuration.h
@@ -9,8 +9,9 @@
#define SDSUPPORT 1
//Acceleration settings
-float full_velocity_units = 10.0; // the units between minimum and G1 move feedrate
-float min_units_per_second = 35.0; // the minimum feedrate
+float full_velocity_units = 0.6; // the units between minimum and G1 move feedrate
+float min_units_per_second = 60.0; // the minimum feedrate
+float min_constant_speed_units = 0.6; // the minimum units of an accelerated move that must be done at constant speed
// THERMOCOUPLE SUPPORT UNTESTED... USE WITH CAUTION!!!!
const bool USE_THERMISTOR = true; //Set to false if using thermocouple